Commit 6533aadc21270052d8d05835b1e30d8b13a2f164

Shawn O. Pearce 2008-10-31T18:23:01

Drop the _t suffix as it is a POSIX reserved namespace Signed-off-by: Shawn O. Pearce <spearce@spearce.org>

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
diff --git a/CONVENTIONS b/CONVENTIONS
index 4b09c08..e3c6728 100644
--- a/CONVENTIONS
+++ b/CONVENTIONS
@@ -12,7 +12,15 @@ All #define macros start with 'GIT_'.
 Type Definitions
 ----------------
 
-All types end in '_t'; for example git_oid_t or git_odb_t.
+Most types should be opaque, e.g.:
+
+----
+	typedef struct git_odb git_odb;
+----
+
+with allocation functions returning an "instance" created within
+the library, and not within the application.  This allows the type
+to grow (or shrink) in size without rebuilding client code.
 
 
 Public Exported Function Definitions
diff --git a/src/git_commit.c b/src/git_commit.c
index ed6e85b..5e98d79 100644
--- a/src/git_commit.c
+++ b/src/git_commit.c
@@ -35,7 +35,7 @@
 
 #include "git_commit.h"
 
-const git_oid_t *git_commit_id(git_commit_t *c)
+const git_oid *git_commit_id(git_commit *c)
 {
 	return &c->id;
 }
diff --git a/src/git_commit.h b/src/git_commit.h
index 05bf671..8c7833b 100644
--- a/src/git_commit.h
+++ b/src/git_commit.h
@@ -50,10 +50,10 @@
 GIT_BEGIN_DECL
 
 /** Parsed representation of a commit object. */
-typedef struct git_commit_t git_commit_t;
+typedef struct git_commit git_commit;
 #ifdef GIT__PRIVATE
-struct git_commit_t {
-	git_oid_t id;
+struct git_commit {
+	git_oid id;
 	time_t commit_time;
 	unsigned parsed:1,
 	         flags:26;
@@ -66,17 +66,17 @@ struct git_commit_t {
  * @param id identity of the commit to locate.  If the object is
  *        an annotated tag it will be peeled back to the commit.
  * @return the commit; NULL if the commit does not exist in the
- *         pool's git_odb_t, or if the commit is present but is
+ *         pool's git_odb, or if the commit is present but is
  *         too malformed to be parsed successfully.
  */
-GIT_EXTERN(git_commit_t*) git_commit_parse(git_revp_t *pool, const git_oid_t *id);
+GIT_EXTERN(git_commit*) git_commit_parse(git_revp *pool, const git_oid *id);
 
 /**
  * Get the id of a commit.
  * @param commit a previously parsed commit.
  * @return object identity for the commit.
  */
-GIT_EXTERN(const git_oid_t*) git_commit_id(git_commit_t *commit);
+GIT_EXTERN(const git_oid*) git_commit_id(git_commit *commit);
 
 /**
  * Get the application data address.
@@ -85,7 +85,7 @@ GIT_EXTERN(const git_oid_t*) git_commit_id(git_commit_t *commit);
  *         Applications should cast to something like
  *         'struct mydata*' in order to access fields.
  */
-GIT_EXTERN(void*) git_commit_appdata(git_commit_t *commit);
+GIT_EXTERN(void*) git_commit_appdata(git_commit *commit);
 
 /** @} */
 GIT_END_DECL
diff --git a/src/git_common.h b/src/git_common.h
index 791826c..c9c7b0e 100644
--- a/src/git_common.h
+++ b/src/git_common.h
@@ -80,7 +80,7 @@ GIT_BEGIN_DECL
 #define GIT_ENOTFOUND (GIT_ERROR - 2)
 
 /** A revision traversal pool. */
-typedef struct git_revp_t git_revp_t;
+typedef struct git_revp git_revp;
 
 /** @} */
 GIT_END_DECL
diff --git a/src/git_odb.c b/src/git_odb.c
index d7ae061..a920633 100644
--- a/src/git_odb.c
+++ b/src/git_odb.c
@@ -35,21 +35,21 @@
 
 #include "git_odb.h"
 
-struct git_odb_t {
+struct git_odb {
 	/** Path to the "objects" directory. */
 	const char *path;
 
 	/** Alternate databases to search. */
-	git_odb_t **alternates;
+	git_odb **alternates;
 
 	/** Number of alternates available. */
 	unsigned n_alternates;
 };
 
 int git_odb_read(
-	git_sobj_t *out,
-	git_odb_t *db,
-	const git_oid_t *id)
+	git_sobj *out,
+	git_odb *db,
+	const git_oid *id)
 {
 	if (!git_odb__read_packed(out, db, id))
 		return GIT_SUCCESS;
diff --git a/src/git_odb.h b/src/git_odb.h
index 8e0a161..5069c19 100644
--- a/src/git_odb.h
+++ b/src/git_odb.h
@@ -50,7 +50,7 @@
 GIT_BEGIN_DECL
 
 /** An open object database handle. */
-typedef struct git_odb_t git_odb_t;
+typedef struct git_odb git_odb;
 
 /**
  * Open an object database for read/write access.
@@ -60,14 +60,14 @@ typedef struct git_odb_t git_odb_t;
  * @return GIT_SUCCESS if the database opened; otherwise an error
  *         code describing why the open was not possible.
  */
-GIT_EXTERN(int) git_odb_open(git_odb_t **out, const char *objects_dir);
+GIT_EXTERN(int) git_odb_open(git_odb **out, const char *objects_dir);
 
 /**
  * Close an open object database.
  * @param db database pointer to close.  If NULL no action is taken.
  *           The pointer is set to NULL when the close is completed.
  */
-GIT_EXTERN(void) git_odb_close(git_odb_t **db);
+GIT_EXTERN(void) git_odb_close(git_odb **db);
 
 /** Basic type (loose or packed) of any Git object. */
 typedef enum {
@@ -80,14 +80,14 @@ typedef enum {
 	GIT_OBJ__EXT2 = 5,      /**< Reserved for future use. */
 	GIT_OBJ_OFS_DELTA = 6,  /**< A delta, base is given by an offset. */
 	GIT_OBJ_REF_DELTA = 7,  /**< A delta, base is given by object id. */
-} git_otype_t;
+} git_otype;
 
 /** A small object read from the database. */
 typedef struct {
 	void *data;            /**< Raw, decompressed object data. */
 	size_t len  ;          /**< Total number of bytes in data. */
-	git_otype_t type;      /**< Type of this object. */
-} git_sobj_t;
+	git_otype type;      /**< Type of this object. */
+} git_sobj;
 
 /**
  * Read a small object from the database.
@@ -101,7 +101,7 @@ typedef struct {
  * - GIT_SUCCESS if the object was read;
  * - GIT_ENOTFOUND if the object is not in the database.
  */
-GIT_EXTERN(int) git_odb_read(git_sobj_t *out, git_odb_t *db, const git_oid_t *id);
+GIT_EXTERN(int) git_odb_read(git_sobj *out, git_odb *db, const git_oid *id);
 
 /**
  * Read a small object from the database using only pack files.
@@ -115,7 +115,7 @@ GIT_EXTERN(int) git_odb_read(git_sobj_t *out, git_odb_t *db, const git_oid_t *id
  * - GIT_SUCCESS if the object was read.
  * - GIT_ENOTFOUND if the object is not in the database.
  */
-GIT_EXTERN(int) git_odb__read_packed(git_sobj_t *out, git_odb_t *db, const git_oid_t *id);
+GIT_EXTERN(int) git_odb__read_packed(git_sobj *out, git_odb *db, const git_oid *id);
 
 /**
  * Read a small object from the database using only loose object files.
@@ -129,7 +129,7 @@ GIT_EXTERN(int) git_odb__read_packed(git_sobj_t *out, git_odb_t *db, const git_o
  * - GIT_SUCCESS if the object was read.
  * - GIT_ENOTFOUND if the object is not in the database.
  */
-GIT_EXTERN(int) git_odb__read_loose(git_sobj_t *out, git_odb_t *db, const git_oid_t *id);
+GIT_EXTERN(int) git_odb__read_loose(git_sobj *out, git_odb *db, const git_oid *id);
 
 /**
  * Release all memory used by the sobj structure.
@@ -140,7 +140,7 @@ GIT_EXTERN(int) git_odb__read_loose(git_sobj_t *out, git_odb_t *db, const git_oi
  *
  * @param obj object descriptor to free.
  */
-GIT_EXTERN(void) git_sobj_close(git_sobj_t *obj);
+GIT_EXTERN(void) git_sobj_close(git_sobj *obj);
 
 /** @} */
 GIT_END_DECL
diff --git a/src/git_oid.c b/src/git_oid.c
index b20f1d8..20d191c 100644
--- a/src/git_oid.c
+++ b/src/git_oid.c
@@ -55,7 +55,7 @@ static signed char from_hex[] = {
 -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, /* f0 */
 };
 
-int git_oid_mkstr(git_oid_t *out, const char *str)
+int git_oid_mkstr(git_oid *out, const char *str)
 {
 	int p;
 	for (p = 0; p < sizeof(out->id); p++, str += 2) {
@@ -67,7 +67,7 @@ int git_oid_mkstr(git_oid_t *out, const char *str)
 	return GIT_SUCCESS;
 }
 
-void git_oid_mkraw(git_oid_t *out, const unsigned char *raw)
+void git_oid_mkraw(git_oid *out, const unsigned char *raw)
 {
 	memcpy(out->id, raw, sizeof(out->id));
 }
diff --git a/src/git_oid.h b/src/git_oid.h
index 9a9e5ab..a24f1bb 100644
--- a/src/git_oid.h
+++ b/src/git_oid.h
@@ -52,7 +52,7 @@ typedef struct
 {
 	/** raw binary formatted id */
 	unsigned char id[20];
-} git_oid_t;
+} git_oid;
 
 /**
  * Parse a hex formatted object id into a git_oid.
@@ -62,14 +62,14 @@ typedef struct
  *        needed for an oid encoded in hex (40 bytes).
  * @return GIT_SUCCESS if valid; GIT_ENOTOID on failure.
  */
-GIT_EXTERN(int) git_oid_mkstr(git_oid_t *out, const char *str);
+GIT_EXTERN(int) git_oid_mkstr(git_oid *out, const char *str);
 
 /**
  * Copy an already raw oid into a git_oid structure.
  * @param out oid structure the result is written into.
  * @param raw the raw input bytes to be copied.
  */
-GIT_EXTERN(void) git_oid_mkraw(git_oid_t *out, const unsigned char *raw);
+GIT_EXTERN(void) git_oid_mkraw(git_oid *out, const unsigned char *raw);
 
 /** @} */
 GIT_END_DECL
diff --git a/src/git_revwalk.c b/src/git_revwalk.c
index 5e9e1f2..1088490 100644
--- a/src/git_revwalk.c
+++ b/src/git_revwalk.c
@@ -37,22 +37,22 @@
 #include <stdlib.h>
 #include <string.h>
 
-struct git_revp_attr_t {
+struct git_revp_attr {
 	size_t app_size;
-	int (*app_init)(git_commit_t *, void *);
+	int (*app_init)(git_commit *, void *);
 };
 
-struct git_revp_t {
-	git_odb_t *db;
-	git_revp_attr_t attr;
+struct git_revp {
+	git_odb *db;
+	git_revp_attr attr;
 };
 
 
-git_revp_t *git_revp_alloc(
-	git_odb_t *db,
-	const git_revp_attr_t *attr)
+git_revp *git_revp_alloc(
+	git_odb *db,
+	const git_revp_attr *attr)
 {
-	git_revp_t *walk = malloc(sizeof(*walk));
+	git_revp *walk = malloc(sizeof(*walk));
 	if (!walk)
 		return NULL;
 
@@ -65,7 +65,7 @@ git_revp_t *git_revp_alloc(
 	return walk;
 }
 
-void git_revp_free(git_revp_t *walk)
+void git_revp_free(git_revp *walk)
 {
 	free(walk);
 }
diff --git a/src/git_revwalk.h b/src/git_revwalk.h
index e7ed799..5ad6372 100644
--- a/src/git_revwalk.h
+++ b/src/git_revwalk.h
@@ -50,7 +50,7 @@
 GIT_BEGIN_DECL
 
 /** Configuration of a revision pool. */
-typedef struct git_revp_attr_t git_revp_attr_t;
+typedef struct git_revp_attr git_revp_attr;
 
 /**
  * Allocate an empty pool configuration.
@@ -61,13 +61,13 @@ typedef struct git_revp_attr_t git_revp_attr_t;
  * @return a new configuration block.
  *         NULL if there is insufficient memory.
  */
-GIT_EXTERN(git_revp_attr_t*) git_revp_attr_alloc(void);
+GIT_EXTERN(git_revp_attr*) git_revp_attr_alloc(void);
 
 /**
  * Setup the application's per-commit data allocation.
  *
  * If size is non-zero the requested number of bytes is allocated
  * alongside every git_commit_t used by the revision pool, allowing
  * constant-time access to per-commit application data.
  *
  * If init is not NULL the function is invoked with the commit and
@@ -81,22 +81,22 @@ GIT_EXTERN(git_revp_attr_t*) git_revp_attr_alloc(void);
  *
  * @param attr the pool configuration to adjust.
  * @param size number of bytes required by the application on
- *        each rev_commit_t instance within the pool.
+ *        each rev_commit instance within the pool.
  * @param init optional callback function to initialize the
  *        application data space.  If NULL the application
  *        space will be zeroed.  If supplied the application
  *        space may contain random garbage.
  */
 GIT_EXTERN(void) git_revp_attr_appdata(
-	git_revp_attr_t *attr,
+	git_revp_attr *attr,
 	size_t size,
-	int (*init)(git_commit_t *, void *));
+	int (*init)(git_commit *, void *));
 
 /**
  * Free a pool configuration.
  * @param attr the configuration to free.  No-op if NULL.
  */
-GIT_EXTERN(void) git_revp_attr_free(git_revp_attr_t *attr);
+GIT_EXTERN(void) git_revp_attr_free(git_revp_attr *attr);
 
 /**
  * Allocate a new revision traversal pool.
@@ -111,42 +111,42 @@ GIT_EXTERN(void) git_revp_attr_free(git_revp_attr_t *attr);
  *        NULL to use a default configuration.
  * @return the new traversal handle; NULL if memory is exhausted.
  */
-GIT_EXTERN(git_revp_t*) git_revp_alloc(
-	git_odb_t *db,
-	const git_revp_attr_t *attr);
+GIT_EXTERN(git_revp*) git_revp_alloc(
+	git_odb *db,
+	const git_revp_attr *attr);
 
 /**
  * Reset the traversal machinary for reuse.
  * @param pool traversal handle to reset.
  */
-GIT_EXTERN(void) git_revp_reset(git_revp_t *pool);
+GIT_EXTERN(void) git_revp_reset(git_revp *pool);
 
 /**
  * Mark an object to start traversal from.
  * @param pool the pool being used for the traversal.
  * @param commit the commit the commit to start from.
  */
-GIT_EXTERN(void) git_revp_pushc(git_revp_t *pool, git_commit_t *commit);
+GIT_EXTERN(void) git_revp_pushc(git_revp *pool, git_commit *commit);
 
 /**
  * Mark a commit (and its ancestors) uninteresting for the output.
  * @param pool the pool being used for the traversal.
  * @param commit the commit the commit to start from.
  */
-GIT_EXTERN(void) git_revp_hidec(git_revp_t *pool, git_commit_t *commit);
+GIT_EXTERN(void) git_revp_hidec(git_revp *pool, git_commit *commit);
 
 /**
  * Get the next commit from the revision traversal.
  * @param pool the pool to pop the commit from.
  * @return next commit; NULL if there is no more output.
  */
-GIT_EXTERN(git_commit_t*) git_revp_nextc(git_revp_t *pool);
+GIT_EXTERN(git_commit*) git_revp_nextc(git_revp *pool);
 
 /**
  * Free a revwalk previously allocated.
  * @param pool traversal handle to close.  If NULL nothing occurs.
  */
-GIT_EXTERN(void) git_revp_free(git_revp_t *pool);
+GIT_EXTERN(void) git_revp_free(git_revp *pool);
 
 /** @} */
 GIT_END_DECL
@@ -61,13 +61,13 @@ typedef struct git_revp_attr_t git_revp_attr_t;
  *
  * If size is non-zero the requested number of bytes is allocated
- * alongside every git_commit_t used by the revision pool, allowing
+ * alongside every git_commit used by the revision pool, allowing
  * constant-time access to per-commit application data.
  *